@@ -49,6 +49,7 @@ namespace Pinta.Core
 		public Gtk.Action SavePalette { get; private set; }
 		public Gtk.Action ResetPalette { get; private set; }
 		public Gtk.Action ResizePalette { get; private set; }
+		public Gtk.Action AddinManager { get; private set; }
 		
 		private string lastPaletteDir = null;
 		
@@ -60,6 +61,7 @@ namespace Pinta.Core
 			fact.Add ("Menu.Edit.FillSelection.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("Menu.Edit.FillSelection.png")));
 			fact.Add ("Menu.Edit.InvertSelection.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("Menu.Edit.InvertSelection.png")));
 			fact.Add ("Menu.Edit.SelectAll.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("Menu.Edit.SelectAll.png")));
+			fact.Add ("Menu.Edit.Addins.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("Menu.Edit.Addins.png")));
 			fact.AddDefault ();
 			
 			Undo = new Gtk.Action ("Undo", Catalog.GetString ("Undo"), null, Stock.Undo);
@@ -79,6 +81,8 @@ namespace Pinta.Core
 			SavePalette = new Gtk.Action ("SavePalette", Catalog.GetString ("Save As..."), null, Stock.Save);
 			ResetPalette = new Gtk.Action ("ResetPalette", Catalog.GetString ("Reset to Default"), null, Stock.RevertToSaved);
 			ResizePalette = new Gtk.Action ("ResizePalette", Catalog.GetString ("Set Number of Colors"), null, "Menu.Image.Resize.png");
+
+			AddinManager = new Gtk.Action ("AddinManager", Catalog.GetString ("Add-in Manager"), null, "Menu.Edit.Addins.png");
 			
 			Undo.IsImportant = true;
 			Undo.Sensitive = false;
@@ -124,6 +128,9 @@ namespace Pinta.Core
 			palette_menu.Append (SavePalette.CreateMenuItem ());
 			palette_menu.Append (ResetPalette.CreateMenuItem ());
 			palette_menu.Append (ResizePalette.CreateMenuItem ());
+
+			menu.AppendSeparator ();
+			menu.Append (AddinManager.CreateMenuItem ());
 		}
 
 		public void CreateHistoryWindowToolBar (Gtk.Toolbar toolbar)
@@ -138,7 +145,6 @@ namespace Pinta.Core
 			EraseSelection.Activated += HandlePintaCoreActionsEditEraseSelectionActivated;
 			SelectAll.Activated += HandlePintaCoreActionsEditSelectAllActivated;
 			FillSelection.Activated += HandlePintaCoreActionsEditFillSelectionActivated;
-			Paste.Activated += HandlerPintaCoreActionsEditPasteActivated;
 			Copy.Activated += HandlerPintaCoreActionsEditCopyActivated;
 			Undo.Activated += HandlerPintaCoreActionsEditUndoActivated;
 			Redo.Activated += HandlerPintaCoreActionsEditRedoActivated;
@@ -227,71 +233,6 @@ namespace Pinta.Core
 			doc.Workspace.Invalidate ();
 		}
 
-		private void HandlerPintaCoreActionsEditPasteActivated (object sender, EventArgs e)
-		{
-			Document doc = PintaCore.Workspace.ActiveDocument;
-
-			PintaCore.Tools.Commit ();
-
-			Gtk.Clipboard cb = Gtk.Clipboard.Get (Gdk.Atom.Intern ("CLIPBOARD", false));
-			
-			Path p;
-
-			// Don't dispose this, as we're going to give it to the history
-			Gdk.Pixbuf image = cb.WaitForImage ();
-
-			if (image == null)
-				return;
-
-			Gdk.Size canvas_size = PintaCore.Workspace.ImageSize;
-
-			// If the image being pasted is larger than the canvas size, allow the user to optionally resize the canvas
-			if (image.Width > canvas_size.Width || image.Height > canvas_size.Height)
-			{
-				string message = Catalog.GetString ("The image being pasted is larger than the canvas size. What would you like to do?");
-
-				var enlarge_dialog = new MessageDialog (PintaCore.Chrome.MainWindow, DialogFlags.Modal, MessageType.Question, ButtonsType.None, message);
-				enlarge_dialog.AddButton (Catalog.GetString ("Expand canvas"), ResponseType.Accept);
-				enlarge_dialog.AddButton (Catalog.GetString ("Don't change canvas size"), ResponseType.Reject);
-				enlarge_dialog.AddButton (Stock.Cancel, ResponseType.Cancel);
-				enlarge_dialog.DefaultResponse = ResponseType.Accept;
-
-				ResponseType response = (ResponseType)enlarge_dialog.Run ();
-				enlarge_dialog.Destroy ();
-
-				if (response == ResponseType.Accept)
-				{
-					PintaCore.Workspace.ResizeCanvas (image.Width, image.Height, Pinta.Core.Anchor.Center);
-					PintaCore.Actions.View.UpdateCanvasScale ();
-				}
-				else if (response == ResponseType.Cancel || response == ResponseType.DeleteEvent)
-				{
-					return;
-				}
-			}
-
-			// Copy the paste to the temp layer
-			doc.CreateSelectionLayer ();
-			doc.ShowSelectionLayer = true;
-
-			using (Cairo.Context g = new Cairo.Context (doc.SelectionLayer.Surface)) {
-				g.DrawPixbuf (image, new Cairo.Point (0, 0));
-				p = g.CreateRectanglePath (new Rectangle (0, 0, image.Width, image.Height));
-			}
-
-			PintaCore.Tools.SetCurrentTool (Catalog.GetString ("Move Selected Pixels"));
-			
-			Path old_path = doc.SelectionPath;
-			bool old_show_selection = doc.ShowSelection;
-
-			doc.SelectionPath = p;
-			doc.ShowSelection = true;
-
-			doc.Workspace.Invalidate ();
-
-			doc.History.PushNewItem (new PasteHistoryItem (image, old_path, old_show_selection));
-		}
-
 		private void HandlerPintaCoreActionsEditCopyActivated (object sender, EventArgs e)
 		{
 			Document doc = PintaCore.Workspace.ActiveDocument;
