@@ -32,6 +32,7 @@ namespace Pinta.Core
 	public class ImageActions
 	{
 		public Gtk.Action CropToSelection { get; private set; }
+		public Gtk.Action AutoCrop { get; private set; }
 		public Gtk.Action Resize { get; private set; }
 		public Gtk.Action CanvasSize { get; private set; }
 		public Gtk.Action FlipHorizontal { get; private set; }
@@ -56,6 +57,7 @@ namespace Pinta.Core
 			fact.AddDefault ();
 			
 			CropToSelection = new Gtk.Action ("CropToSelection", Catalog.GetString ("Crop to Selection"), null, "Menu.Image.Crop.png");
+			AutoCrop = new Gtk.Action ("AutoCrop", Catalog.GetString ("Auto Crop"), null, "Menu.Image.Crop.png");
 			Resize = new Gtk.Action ("Resize", Catalog.GetString ("Resize Image..."), null, "Menu.Image.Resize.png");
 			CanvasSize = new Gtk.Action ("CanvasSize", Catalog.GetString ("Resize Canvas..."), null, "Menu.Image.CanvasSize.png");
 			FlipHorizontal = new Gtk.Action ("FlipHorizontal", Catalog.GetString ("Flip Horizontal"), null, "Menu.Image.FlipHorizontal.png");
@@ -72,6 +74,7 @@ namespace Pinta.Core
 		public void CreateMainMenu (Gtk.Menu menu)
 		{
 			menu.Append (CropToSelection.CreateAcceleratedMenuItem (Gdk.Key.X, Gdk.ModifierType.ControlMask | Gdk.ModifierType.ShiftMask));
+			menu.Append (AutoCrop.CreateAcceleratedMenuItem (Gdk.Key.X, Gdk.ModifierType.Mod1Mask | Gdk.ModifierType.ControlMask));
 			menu.Append (Resize.CreateAcceleratedMenuItem (Gdk.Key.R, Gdk.ModifierType.ControlMask));
 			menu.Append (CanvasSize.CreateAcceleratedMenuItem (Gdk.Key.R, Gdk.ModifierType.ControlMask | Gdk.ModifierType.ShiftMask));
 			menu.AppendSeparator ();
@@ -94,6 +97,7 @@ namespace Pinta.Core
 			RotateCW.Activated += HandlePintaCoreActionsImageRotateCWActivated;
 			RotateCCW.Activated += HandlePintaCoreActionsImageRotateCCWActivated;
 			CropToSelection.Activated += HandlePintaCoreActionsImageCropToSelectionActivated;
+			AutoCrop.Activated += HandlePintaCoreActionsImageAutoCropActivated;
 		}
 		#endregion
 
@@ -105,6 +109,8 @@ namespace Pinta.Core
 			PintaCore.Tools.Commit ();
 			doc.RotateImageCCW ();
 
+			doc.ResetSelectionPath ();
+
 			doc.History.PushNewItem (new InvertHistoryItem (InvertType.Rotate90CCW));
 		}
 
@@ -115,6 +121,8 @@ namespace Pinta.Core
 			PintaCore.Tools.Commit ();
 			doc.RotateImageCW ();
 
+			doc.ResetSelectionPath ();
+
 			doc.History.PushNewItem (new InvertHistoryItem (InvertType.Rotate90CW));
 		}
 
@@ -144,6 +152,8 @@ namespace Pinta.Core
 			PintaCore.Tools.Commit ();
 			doc.RotateImage180 ();
 
+			doc.ResetSelectionPath ();
+
 			doc.History.PushNewItem (new InvertHistoryItem (InvertType.Rotate180));
 		}
 
@@ -175,32 +185,117 @@ namespace Pinta.Core
 
 			Gdk.Rectangle rect = doc.GetSelectedBounds (true);
 
-			ResizeHistoryItem hist = new ResizeHistoryItem (doc.ImageSize);
+			CropImageToRectangle (doc, rect);
+		}
 
+		private void HandlePintaCoreActionsImageAutoCropActivated (object sender, EventArgs e)
+		{
+			Document doc = PintaCore.Workspace.ActiveDocument;
+
+			PintaCore.Tools.Commit ();
+
+			Cairo.ImageSurface image = doc.CurrentLayer.Surface;
+			Gdk.Rectangle rect = image.GetBounds ();
+
+			Cairo.Color borderColor = image.GetPixel (0, 0);
+			bool cropSide = true;
+			int depth = -1;
+
+			//From the top down
+			while (cropSide) {
+				depth++;
+				for (int i = 0; i < image.Width; i++) {
+					if (!borderColor.Equals(image.GetPixel (i, depth))) {
+						cropSide = false;
+						break;
+					}
+				}
+				//Check if the image is blank/mono-coloured, only need to do it on this scan
+				if (depth == image.Height)
+					return;
+			}
+
+			rect = new Gdk.Rectangle (rect.X, rect.Y + depth, rect.Width, rect.Height - depth);
+
+			depth = image.Height;
+			cropSide = true;
+			//From the bottom up
+			while (cropSide) {
+				depth--;
+				for (int i = 0; i < image.Width; i++) {
+					if (!borderColor.Equals(image.GetPixel (i, depth))) {
+						cropSide = false;
+						break;
+					}
+				}
+
+			}
+
+			rect = new Gdk.Rectangle (rect.X, rect.Y, rect.Width, depth - rect.Y);
+
+			depth = 0;
+			cropSide = true;
+			//From left to right
+			while (cropSide) {
+				depth++;
+				for (int i = 0; i < image.Height; i++) {
+					if (!borderColor.Equals(image.GetPixel (depth, i))) {
+						cropSide = false;
+						break;
+					}
+				}
+
+			}
+
+			rect = new Gdk.Rectangle (rect.X + depth, rect.Y, rect.Width - depth, rect.Height);
+
+			depth = image.Width;
+			cropSide = true;
+			//From right to left
+			while (cropSide) {
+				depth--;
+				for (int i = 0; i < image.Height; i++) {
+					if (!borderColor.Equals(image.GetPixel (depth, i))) {
+						cropSide = false;
+						break;
+					}
+				}
+
+			}
+
+			rect = new Gdk.Rectangle (rect.X, rect.Y, depth - rect.X, rect.Height);
+
+			CropImageToRectangle (doc, rect);
+		}
+		#endregion
+
+		static void CropImageToRectangle (Document doc, Gdk.Rectangle rect)
+		{
+			ResizeHistoryItem hist = new ResizeHistoryItem (doc.ImageSize);
+			
 			hist.Icon = "Menu.Image.Crop.png";
 			hist.Text = Catalog.GetString ("Crop to Selection");
 			hist.TakeSnapshotOfImage ();
 			hist.RestorePath = doc.SelectionPath.Clone ();
-
+			
 			PintaCore.Chrome.Canvas.GdkWindow.FreezeUpdates ();
-
+			
 			double original_scale = doc.Workspace.Scale;
 			doc.ImageSize = rect.Size;
 			doc.Workspace.CanvasSize = rect.Size;
 			doc.Workspace.Scale = original_scale;
-
+			
 			PintaCore.Actions.View.UpdateCanvasScale ();
-
+			
 			PintaCore.Chrome.Canvas.GdkWindow.ThawUpdates ();
-
+			
 			foreach (var layer in doc.Layers)
 				layer.Crop (rect, doc.SelectionPath);
-
+			
 			doc.History.PushNewItem (hist);
 			doc.ResetSelectionPath ();
-
+			
 			doc.Workspace.Invalidate ();
 		}
-		#endregion
 	}
 }
