@@ -47,6 +47,18 @@ namespace Pinta.Core
 
 		public ToolBarComboBox ZoomComboBox { get; private set; }
 		public string[] ZoomCollection { get; private set; }
+
+		private string old_zoom_text = "";
+		private bool zoom_to_window_activated = false;
+
+		public bool ZoomToWindowActivated { 
+			get { return zoom_to_window_activated; }
+			set
+			{
+				zoom_to_window_activated = value;
+				old_zoom_text = ZoomComboBox.ComboBox.ActiveText;
+			}
+		}
 		
 		public ViewActions ()
 		{
@@ -73,8 +85,8 @@ namespace Pinta.Core
 			Centimeters = new Gtk.RadioAction ("Centimeters", Catalog.GetString ("Centimeters"), null, null, 2);
 			Fullscreen = new Gtk.Action ("Fullscreen", Catalog.GetString ("Fullscreen"), null, Stock.Fullscreen);
 
-			ZoomCollection = new string[] { "3600%", "2400%", "1600%", "1200%", "800%", "700%", "600%", "500%", "400%", "300%", "200%", "100%", "66%", "50%", "33%", "25%", "16%", "12%", "8%", "5%", "Window" };
-			ZoomComboBox = new ToolBarComboBox (75, 11, true, ZoomCollection);
+			ZoomCollection = new string[] { "3600%", "2400%", "1600%", "1200%", "800%", "700%", "600%", "500%", "400%", "300%", "200%", "175%", "150%", "125%", "100%", "66%", "50%", "33%", "25%", "16%", "12%", "8%", "5%", Catalog.GetString ("Window") };
+			ZoomComboBox = new ToolBarComboBox (75, DefaultZoomIndex(), true, ZoomCollection);
 
 			// Make sure these are the same group so only one will be selected at a time
 			Inches.Group = Pixels.Group;
@@ -167,7 +179,7 @@ namespace Pinta.Core
 			string text = PintaCore.Actions.View.ZoomComboBox.ComboBox.ActiveText;
 			double percent;
 
-			if (!double.TryParse (text, out percent)) {
+			if (!TryParsePercent (text, out percent)) {
 				(PintaCore.Actions.View.ZoomComboBox.ComboBox as Gtk.ComboBoxEntry).Entry.Text = temp_zoom;
 				return;
 			}
@@ -177,6 +189,14 @@ namespace Pinta.Core
 		}
 		#endregion
 
+		/// <summary>
+		/// Converts the string representation of a percent (with or without a '%' sign) to a numeric value
+		/// </summary>
+		public static bool TryParsePercent (string text, out double percent)
+		{
+			return double.TryParse (text.Trim ('%'), out percent);
+		}
+
 		public void SuspendZoomUpdate ()
 		{
 			suspend_zoom_change = true;
@@ -191,16 +211,22 @@ namespace Pinta.Core
 		{
 			string text = PintaCore.Actions.View.ZoomComboBox.ComboBox.ActiveText;
 
-			if (text == Catalog.GetString ("Window")) {
+			// stay in "Zoom to Window" mode if this function was called without the zoom level being changed by the user (e.g. if the 
+			// image was rotated or cropped) and "Zoom to Window" mode is active
+			if (text == Catalog.GetString ("Window") || (ZoomToWindowActivated && old_zoom_text == text))
+			{
 				PintaCore.Actions.View.ZoomToWindow.Activate ();
+				ZoomToWindowActivated = true;
 				return;
 			}
-
-			text = text.Trim ('%');
+			else
+			{
+				ZoomToWindowActivated = false;
+			}
 
 			double percent;
 
-			if (!double.TryParse (text, out percent))
+			if (!TryParsePercent (text, out percent))
 				return;
 
 			percent = Math.Min (percent, 3600);
@@ -212,7 +238,12 @@ namespace Pinta.Core
 		#region Action Handlers
 		private void HandlePintaCoreActionsViewActualSizeActivated (object sender, EventArgs e)
 		{
-			PintaCore.Actions.View.ZoomComboBox.ComboBox.Active = 11;
+			int default_zoom = DefaultZoomIndex ();
+			if (ZoomComboBox.ComboBox.Active != default_zoom)
+			{
+				ZoomComboBox.ComboBox.Active = default_zoom;
+				UpdateCanvasScale ();
+			}
 		}
 
 		private void HandlePintaCoreActionsViewZoomComboBoxComboBoxChanged (object sender, EventArgs e)
@@ -233,5 +264,13 @@ namespace Pinta.Core
 			PintaCore.Workspace.ActiveDocument.Workspace.ZoomIn ();
 		}
 		#endregion
+
+		/// <summary>
+		/// Returns the index in the ZoomCollection of the default zoom level
+		/// </summary>
+		private int DefaultZoomIndex()
+		{
+			return Array.IndexOf(ZoomCollection, "100%");
+		}
 	}
 }
\ No newline at end of file
