@@ -243,6 +243,8 @@ namespace Pinta.Core
 
 			if (selection_path != null)
 				(selection_path as IDisposable).Dispose ();
+
+            Workspace.History.Clear ();
 		}
 
 		public Context CreateClippedContext ()
@@ -612,10 +614,10 @@ namespace Pinta.Core
 			hist.Text = Catalog.GetString ("Resize Canvas");
 			hist.TakeSnapshotOfImage ();
 
-			ImageSize = new Gdk.Size (width, height);
-
 			scale = Workspace.Scale;
 
+			ImageSize = new Gdk.Size (width, height);
+
 			foreach (var layer in Layers)
 				layer.ResizeCanvas (width, height, anchor);
 
@@ -655,37 +657,34 @@ namespace Pinta.Core
 		// Rotate image 180 degrees (flip H+V)
 		public void RotateImage180 ()
 		{
-			foreach (var layer in Layers)
-				layer.Rotate180 ();
-
-			Workspace.Invalidate ();
+			RotateImage (180);
 		}
 
 		public void RotateImageCW ()
 		{
-			foreach (var layer in Layers)
-				layer.Rotate90CW ();
-
-			ImageSize = new Gdk.Size (ImageSize.Height, ImageSize.Width);
-			Workspace.CanvasSize = new Gdk.Size (Workspace.CanvasSize.Height, Workspace.CanvasSize.Width);
-
-			PintaCore.Actions.View.UpdateCanvasScale ();
-
-			Workspace.Invalidate ();
+			RotateImage (90);
 		}
 
 		public void RotateImageCCW ()
 		{
-			foreach (var layer in Layers)
-				layer.Rotate90CCW ();
+			RotateImage (-90);
+		}
 
-			ImageSize = new Gdk.Size (ImageSize.Height, ImageSize.Width);
-			Workspace.CanvasSize = new Gdk.Size (Workspace.CanvasSize.Height, Workspace.CanvasSize.Width);
+		/// <summary>
+		/// Rotates the image by the specified angle (in degrees)
+		/// </summary>
+		private void RotateImage (double angle)
+		{
+			foreach (var layer in Layers)
+			{
+				layer.Rotate (angle);
+			}
+
+			ImageSize = Layer.RotateDimensions (ImageSize, angle);
+			Workspace.CanvasSize = Layer.RotateDimensions (Workspace.CanvasSize, angle);
 
 			PintaCore.Actions.View.UpdateCanvasScale ();
-
 			Workspace.Invalidate ();
-
 		}
 
 		// Returns true if successful, false if canceled
