@@ -255,7 +255,7 @@ namespace Pinta.Core
 		{
 			// Work around a case where we closed a document but haven't updated
 			// the active_document_index yet and it points to the closed document
-			if (HasOpenDocuments && OpenDocuments.Count > active_document_index)
+			if (HasOpenDocuments && active_document_index != -1 && OpenDocuments.Count > active_document_index)
 				PintaCore.Tools.Commit ();
 
 			int index = OpenDocuments.IndexOf (document);
