@@ -13,7 +13,6 @@ using Pinta.Core;
 
 namespace Pinta.Effects
 {
-	//[System.ComponentModel.Composition (typeof (BaseEffect))]
 	public class InvertColorsEffect : BaseEffect
 	{
 		UnaryPixelOp op = new UnaryPixelOps.Invert ();
@@ -22,19 +21,15 @@ namespace Pinta.Effects
 			get { return "Menu.Adjustments.InvertColors.png"; }
 		}
 
-		public override string Text {
+		public override string Name {
 			get { return Mono.Unix.Catalog.GetString ("Invert Colors"); }
 		}
-
-		public override EffectAdjustment EffectOrAdjustment {
-			get { return EffectAdjustment.Adjustment; }
-		}
 		
 		public override Gdk.Key AdjustmentMenuKey {
 			get { return Gdk.Key.I; }
 		}
 		
-		public override void RenderEffect (ImageSurface src, ImageSurface dest, Gdk.Rectangle[] rois)
+		public override void Render (ImageSurface src, ImageSurface dest, Gdk.Rectangle[] rois)
 		{
 			op.Apply (dest, src, rois);
 		}
