@@ -13,14 +13,13 @@ using Pinta.Core;
 
 namespace Pinta.Effects
 {
-	//[System.ComponentModel.Composition (typeof (BaseEffect))]
 	public class LevelsEffect : BaseEffect
 	{		
 		public override string Icon {
 			get { return "Menu.Adjustments.Levels.png"; }
 		}
 
-		public override string Text {
+		public override string Name {
 			get { return Mono.Unix.Catalog.GetString ("Levels"); }
 		}
 
@@ -28,10 +27,6 @@ namespace Pinta.Effects
 			get { return true; }
 		}
 
-		public override EffectAdjustment EffectOrAdjustment {
-			get { return EffectAdjustment.Adjustment; }
-		}
-
 		public override Gdk.Key AdjustmentMenuKey {
 			get { return Gdk.Key.L; }
 		}
@@ -50,7 +45,7 @@ namespace Pinta.Effects
 		public override bool LaunchConfiguration ()
 		{			
 			var dialog = new LevelsDialog (Data);
-			dialog.Title = Text;
+			dialog.Title = Name;
 			dialog.Icon = PintaCore.Resources.GetIcon (Icon);
 			
 			int response = dialog.Run ();
@@ -60,7 +55,7 @@ namespace Pinta.Effects
 			return (response == (int)Gtk.ResponseType.Ok);
 		}
 		
-		public override void RenderEffect (ImageSurface src, ImageSurface dest, Gdk.Rectangle[] rois)
+		public override void Render (ImageSurface src, ImageSurface dest, Gdk.Rectangle[] rois)
 		{
 			Data.Levels.Apply (dest, src, rois);
 		}
