@@ -15,14 +15,13 @@ using Mono.Unix;
 
 namespace Pinta.Effects
 {
-	//[System.ComponentModel.Composition (typeof (BaseEffect))]
 	public class JuliaFractalEffect : BaseEffect
 	{
 		public override string Icon {
 			get { return "Menu.Effects.Render.JuliaFractal.png"; }
 		}
 
-		public override string Text {
+		public override string Name {
 			get { return Catalog.GetString ("Julia Fractal"); }
 		}
 
@@ -65,7 +64,7 @@ namespace Pinta.Effects
 			return c;
 		}
 
-		unsafe public override void RenderEffect (ImageSurface src, ImageSurface dst, Gdk.Rectangle[] rois)
+		unsafe public override void Render (ImageSurface src, ImageSurface dst, Gdk.Rectangle[] rois)
 		{
 			const double jr = 0.3125;
 			const double ji = 0.03;
