@@ -15,14 +15,13 @@ using Mono.Unix;
 
 namespace Pinta.Effects
 {
-	//[System.ComponentModel.Composition (typeof (BaseEffect))]
 	public class MotionBlurEffect : BaseEffect
 	{
 		public override string Icon {
 			get { return "Menu.Effects.Blurs.MotionBlur.png"; }
 		}
 
-		public override string Text {
+		public override string Name {
 			get { return Catalog.GetString ("Motion Blur"); }
 		}
 
@@ -47,7 +46,7 @@ namespace Pinta.Effects
 		}
 
 		#region Algorithm Code Ported From PDN
-		public unsafe override void RenderEffect (ImageSurface src, ImageSurface dst, Gdk.Rectangle[] rois)
+		public unsafe override void Render (ImageSurface src, ImageSurface dst, Gdk.Rectangle[] rois)
 		{
 			PointD start = new PointD (0, 0);
 			double theta = ((double)(Data.Angle + 180) * 2 * Math.PI) / 360.0;
