@@ -31,7 +31,6 @@ using Pinta.Core;
 
 namespace Pinta.Tools.Brushes
 {
-	//[System.ComponentModel.Composition (typeof (BasePaintBrush))]
 	public class SplatterBrush : PaintBrush
 	{
 		public override string Name {
@@ -44,7 +43,19 @@ namespace Pinta.Tools.Brushes
 		
 		protected override Gdk.Rectangle OnMouseMove (int x, int y, int lastX, int lastY)
 		{
-			int size = Random.Next (2, (int)G.LineWidth);
+			int line_width = (int)G.LineWidth;
+			int size;
+
+			// we want a minimum size of 2 for the splatter (except for when the brush width is 1), since a splatter of size 1 is very small
+			if (line_width == 1)
+			{
+				size = 1;
+			}
+			else
+			{
+				size = Random.Next (2, line_width);
+			}
+
 			Rectangle r = new Rectangle (x - Random.Next (-15, 15), y - Random.Next (-15, 15), size, size);
 
 			double rx = r.Width / 2;
