@@ -40,6 +40,9 @@ namespace Pinta.Tools
 		public override string StatusBarText {
 			get { return Catalog.GetString ("Left click to place cursor, then type desired text. Text color is primary color."); }
 		}
+		public override Gdk.Cursor DefaultCursor {
+			get { return new Gdk.Cursor (PintaCore.Chrome.Canvas.Display, PintaCore.Resources.GetIcon ("Cursor.Text.png"), 8, 0); }
+		}
 
 		#region Constructor
 		public TextTool ()
@@ -47,6 +50,16 @@ namespace Pinta.Tools
 			cursor_hand = new Gdk.Cursor (PintaCore.Chrome.Canvas.Display, PintaCore.Resources.GetIcon ("Tools.Pan.png"), 0, 0);
 			engine = new TextEngine ();
 		}
+
+        static TextTool ()
+        {
+            Gtk.IconFactory fact = new Gtk.IconFactory ();
+            fact.Add ("ShapeTool.Outline.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("ShapeTool.Outline.png")));
+            fact.Add ("ShapeTool.Fill.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("ShapeTool.Fill.png")));
+            fact.Add ("ShapeTool.OutlineFill.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("ShapeTool.OutlineFill.png")));
+            fact.Add ("TextTool.FillBackground.png", new Gtk.IconSet (PintaCore.Resources.GetIcon ("TextTool.FillBackground.png")));
+            fact.AddDefault ();
+        }
 		#endregion
 
 		#region ToolBar
@@ -168,6 +181,7 @@ namespace Pinta.Tools
 				fill_button.AddItem (Catalog.GetString ("Normal"), "ShapeTool.Fill.png", 0);
 				fill_button.AddItem (Catalog.GetString ("Normal and Outline"), "ShapeTool.OutlineFill.png", 1);
 				fill_button.AddItem (Catalog.GetString ("Outline"), "ShapeTool.Outline.png", 2);
+				fill_button.AddItem (Catalog.GetString ("Fill Background"), "TextTool.FillBackground.png", 3);
 
 				fill_button.SelectedItemChanged += HandleBoldButtonToggled;
 			}
@@ -387,8 +401,9 @@ namespace Pinta.Tools
 			set { (outline_width.ComboBox as Gtk.ComboBoxEntry).Entry.Text = value.ToString (); }
 		}
 
-		protected bool StrokeText { get { return (int)fill_button.SelectedItem.Tag >= 1; } }
-		protected bool FillText { get { return (int)fill_button.SelectedItem.Tag <= 1; } }
+		protected bool StrokeText { get { return ((int)fill_button.SelectedItem.Tag >= 1 && (int)fill_button.SelectedItem.Tag != 3); } }
+		protected bool FillText { get { return (int)fill_button.SelectedItem.Tag <= 1 || (int)fill_button.SelectedItem.Tag == 3; } }
+		protected bool BackgroundFill { get { return (int)fill_button.SelectedItem.Tag == 3; } }
 		#endregion
 
 		#region Activation/Deactivation
@@ -590,6 +605,11 @@ namespace Pinta.Tools
 					RedrawText (true, true);
 
 			}
+            else
+            {
+                // If we're not editing, allow the key press to be handled elsewhere (e.g. for selecting another tool).
+                keyHandled = false;
+            }
 
 			args.RetVal = keyHandled;
 		}
@@ -662,6 +682,13 @@ namespace Pinta.Tools
 				g.MoveTo (new Cairo.PointD (engine.Origin.X, engine.Origin.Y));
 				g.Color = PintaCore.Palette.PrimaryColor;
 
+				//Fill in background
+				if (BackgroundFill) {
+					using (var g2 = new Cairo.Context (surf)) {
+						g2.FillRectangle (engine.GetLayoutBounds ().ToCairoRectangle (), PintaCore.Palette.SecondaryColor);
+					}
+				}
+
 				// Draw the text
 				if (FillText)
 					Pango.CairoHelper.ShowLayout (g, engine.Layout);
