@@ -60,20 +60,22 @@ namespace Pinta
 
 		string[] authors = new string[] {
 			"Cameron White",
-			"James Gifford",
-                        "Jean-Michel Bea",
-                        "Jonathan Pobst",
-			"Manish Sinha",
-			"Martin Geier",
-			"Olivier Dufour",
-                        "Robert Nordan"
+			"Jonathan Pobst",
+			"Robert Nordan"
 		};
 
 		string[] oldAuthors = new string[] {
 			"Aaron Bockover",
+			"Adam Doppelt",
+			"Adolfo Jayme Barrientos",
 			"Anirudh Sanjeev",
+			"Cameron White",
+			"Ciprian Mustiata",
+			"Felix Schmutz",
 			"Greg Lowe",
 			"Hanh Pham",
+			"James Gifford",
+			"Jean-Michel Bea",
 			"Joe Hillenbrand",
 			"Jon Rimmer",
 			"Jonathan Pobst",
@@ -81,11 +83,15 @@ namespace Pinta
 			"Khairuddin Ni'am",
 			"Krzysztof Marecki",
 			"Maia Kozheva",
+			"Manish Sinha",
 			"Marco Rolappe",
+			"Martin Geier",
 			"Mathias Fussenegger",
+			"Mikhail Makarov",
 			"Obinou Conseil",
 			"Olivier Dufour",
-			"Richard Cohn"
+			"Richard Cohn",
+			"Robert Nordan"
 		};
 
 		public ScrollBox ()
